@@ -7,6 +7,8 @@ from enum import Enum
 from typing import List
 
 import zephyr.exceptions as exceptions
+from zephyr.filecache import filecache
+from zephyr.filecache import WEEK
 from zephyr.interface import ZephyrInterface
 
 
@@ -95,6 +97,7 @@ class TestManagement(ZephyrInterface):
 
         return resp["key"], resp["id"]
 
+    @filecache(seconds_of_validity=2 * WEEK)
     def get_testcase(self, testcase_key: str, *args, **kwargs):
         """
         Gets a testcase from Zephyr
@@ -432,6 +435,11 @@ class TestManagement(ZephyrInterface):
         else:
             return None
 
+    @filecache(seconds_of_validity=2 * WEEK)
+    def _env_exists(self, env_name: str, project_key: str):
+        envs = self.get_environments(project_key)
+        return env_name in [x["name"] for x in envs]
+
     def post_test_execution(
         self,
         project_key: str,
@@ -468,9 +476,7 @@ class TestManagement(ZephyrInterface):
         url = self.base_url + "/testexecutions"
 
         if env_name is not None:
-            # check if it exists
-            envs = self.get_environments(project_key)
-            if env_name not in [x["name"] for x in envs]:
+            if not self._env_exists(env_name, project_key):
                 env_name = None
 
         payload = dict(
@@ -486,6 +492,17 @@ class TestManagement(ZephyrInterface):
         resp = self.post_request(url, payload)
         return resp["id"]
 
+    @filecache(seconds_of_validity=2 * WEEK)
+    def _find_cycle_key(self, cycle_name: str, proj_key: str):
+        cycles = self.get_all_testcycles(proj_key)
+        cycle_key = None
+        for cycle in cycles:
+            if cycle["name"] == cycle_name:
+                cycle_key = cycle["key"]
+                break
+
+        return cycle_key
+
     def upload_results(
         self,
         cycle_name: str,
@@ -534,13 +551,7 @@ class TestManagement(ZephyrInterface):
             # Cannot upload to a non-existent test
             return False
 
-        # find matching cycle
-        cycles = self.get_all_testcycles(proj_key)
-        cycle_key = None
-        for cycle in cycles:
-            if cycle["name"] == cycle_name:
-                cycle_key = cycle["key"]
-                break
+        cycle_key = self._find_cycle_key(cycle_name, proj_key)
 
         if cycle_key is None:
             # Create new cycle
